@@ -8,7 +8,7 @@ if [ -f /etc/dbconfig-common/tryton-server-postgresql.conf ]; then
     . /etc/dbconfig-common/tryton-server-postgresql.conf
 fi
 
-if [ ! -z $dbc_dbname ]; then
+if [ ! -z "$dbc_dbname" ]; then
     db_name=$dbc_dbname
 fi
 
